==> tine20-allinone_2020.08.8.tar.bz2: Addressbook/js/Addressbook-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ca\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Dades de contacte laborals"

, "Organisation / Unit"
: "Organització / Departament"

, "Business Address"
: "Adreça laboral"

, "Email"
: "Correu electrònic"

, "Telephone Work"
: "Telèfon laboral"

, "Telephone Cellphone"
: "Telèfon mòbil"

, "Telephone Car"
: "Telèfon del cotxe"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: ""

, "URL"
: "URL"

, "Role"
: "Càrrec"

, "Room"
: "Sala"

, "Assistant"
: "Secretari -ària"

, "Assistant Telephone"
: "Telèfon secretari -ària"

, "Private Contact Data"
: "Dades de contacte personals"

, "Private Address"
: "Adreça particular"

, "Email Home"
: "Correu electrònic particular"

, "Telephone Home"
: "Telèfon particular"

, "Telephone Cellphone Private"
: "Mòbil particular"

, "Telephone Fax Home"
: "Fax particular"

, "URL Home"
: "URL personal"

, "Other Data"
: "Informació addicional"

, "Birthday"
: "Data de naixement"

, "Job Title"
: "Professió"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Percent"
: ""

, "Description"
: "Descripció"

, "Members"
: ""

, "Type"
: "Tipus"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Llibreta d'adreces"
 ,"Llibretes d'adreces"

]
, "Contact, Contacts"
: [
  "Contacte"
 ,"Contactes"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "País"

, "City"
: "Població"

, "Postalcode"
: "Codi postal"

, "Region"
: "Província / Regió"

, "Street"
: "Carrer"

, "Street 2"
: "Carrer 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "País (particular)"

, "City (private)"
: "Població (particular)"

, "Postalcode (private)"
: "Codi postal (particular)"

, "Region (private)"
: "Província / Regió (particular)"

, "Street (private)"
: "Carrer (particular)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Correu electrònic (particular)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geoubicació"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Nota"

, "Last Name"
: "Cognom"

, "Display Name"
: "Nom a mostrar"

, "Full Name"
: "Nom complet"

, "First Name"
: "Nom"

, "Middle Name"
: ""

, "Title"
: "Títol"

, "Suffix"
: "Sufix"

, "Company"
: "Empresa"

, "Unit"
: "Departament"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Càrrec"

, "Salutation"
: "Salutació"

, "syncBackendIds"
: ""

, "Car phone"
: "Telèfon del cotxe"

, "Mobile"
: "Mòbil"

, "Mobile (private)"
: "Mòbil particular"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax particular"

, "Phone (private)"
: "Telèfon particular"

, "Pager"
: "Cercapersones"

, "Phone"
: "Telèfon"

, "Timezone"
: "Zona horària"

, "Web"
: "Web"

, "URL (private)"
: "URL (particular)"

, "Label"
: ""

, "Lists"
: ""

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Informació de contacte"

, "Company Address"
: "Adreça de l'empresa"

, "New Contact"
: ""

, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importa contactes"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Particular"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Etiquetes"

, "List Roles"
: ""

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "E-Mail"
: "Correu electrònic"

, "E-Mail (private)"
: "Correu electrònic particular"

, "Web (private)"
: ""

, "Contacts"
: "Contactes"

, "Addressbooks"
: "Llibretes d'adreces"

, "User Account"
: "Compte d'usuari"

, "Quick Search"
: ""

, "Postal Code"
: "Codi postal"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Data de creació"

, "Created By"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Introduïu una descripció"

, "{0} must be given"
: ""

, "Member of List"
: ""

, "Map"
: "Mapa"

, "Company address"
: ""

, "Private address"
: ""

, "CardDAV URL"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Informació personal"

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Tots els contactes"

, "Default Addressbook"
: "Llibreta d'adreces per defecte"

, "The default addressbook for new contacts"
: "La llibreta d'adreces per defecte per a nous contactes"

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Sr."

, "Ms"
: "Sra."

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "manage shared addressbooks"
: "gestiona les llibretes d'adreces compartides"

, "Create new shared addressbook folders"
: "Crea noves llibretes d'adreces compartides"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "llibreta d'adreces personal de %s"

, "All contacts I have read grants for"
: "Tots els contactes sobre els quals tenc permís de lectura"

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Internal Contacts"
: "Contactes interns"

, "List"
: ""

, "Addressbook"
: "Llibreta d'adreces"

, "Contact"
: "Contacte"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Mapa"

, "Preferred Address"
: ""

, "Personal Information"
: "Informació personal"

, "Salutation"
: "Salutació"

, "Title"
: "Títol"

, "Short Name"
: ""

, "First Name"
: "Nom"

, "Middle Name"
: ""

, "Last Name"
: "Cognom"

, "Company"
: "Empresa"

, "Unit"
: "Departament"

, "Display Name"
: "Nom a mostrar"

, "Industry, Industries"
: [
  ""
 ,""

]
, "Job Title"
: "Professió"

, "Birthday (private)"
: ""

, "Contact Information"
: "Informació de contacte"

, "Phone"
: "Telèfon"

, "Mobile"
: "Mòbil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telèfon particular"

, "Mobile (private)"
: "Mòbil particular"

, "Fax (private)"
: "Fax particular"

, "E-Mail"
: "Correu electrònic"

, "E-Mail (private)"
: "Correu electrònic particular"

, "Web"
: "Web"

, "Company Address"
: "Adreça de l'empresa"

, "Street"
: "Carrer"

, "Street 2"
: "Carrer 2"

, "Region"
: "Província / Regió"

, "Postal Code"
: "Codi postal"

, "City"
: "Població"

, "Country"
: "País"

, "Private Address"
: "Adreça particular"

, "Description"
: "Descripció"

, "Enter description"
: "Introduïu una descripció"

, "Groups"
: ""

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "Contacte"
 ,"Contactes"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: ""

, "New Contact"
: ""

, "Addressbook, Addressbooks"
: [
  "Llibreta d'adreces"
 ,"Llibretes d'adreces"

]
, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: "Particular"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Sufix"

, "Birthday"
: "Data de naixement"

, "Job Role"
: "Càrrec"

, "Room"
: "Sala"

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "Web (private)"
: ""

, "Contacts"
: "Contactes"

, "Addressbooks"
: "Llibretes d'adreces"

, "User Account"
: "Compte d'usuari"

, "Quick Search"
: ""

, "Type"
: "Tipus"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Data de creació"

, "Created By"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Lists"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Importa contactes"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Etiquetes"

, "Full Name"
: "Nom complet"

, "Postalcode"
: "Codi postal"

, "Street (private)"
: "Carrer (particular)"

, "City (private)"
: "Població (particular)"

, "Region (private)"
: "Província / Regió (particular)"

, "Postalcode (private)"
: "Codi postal (particular)"

, "Country (private)"
: "País (particular)"

, "Email"
: "Correu electrònic"

, "Car phone"
: "Telèfon del cotxe"

, "Pager"
: "Cercapersones"

, "Email (private)"
: "Correu electrònic (particular)"

, "URL (private)"
: "URL (particular)"

, "Note"
: "Nota"

, "Timezone"
: "Zona horària"

, "Geo"
: "Geoubicació"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: ""

, "Private address"
: ""

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Tots els contactes"

, "Default Addressbook"
: "Llibreta d'adreces per defecte"

, "The default addressbook for new contacts"
: "La llibreta d'adreces per defecte per a nous contactes"

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Sr."

, "Ms"
: "Sra."

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "llibreta d'adreces personal de %s"

, "Business Contact Data"
: "Dades de contacte laborals"

, "Organisation / Unit"
: "Organització / Departament"

, "Business Address"
: "Adreça laboral"

, "Telephone Work"
: "Telèfon laboral"

, "Telephone Cellphone"
: "Telèfon mòbil"

, "Telephone Car"
: "Telèfon del cotxe"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: ""

, "URL"
: "URL"

, "Role"
: "Càrrec"

, "Assistant"
: "Secretari -ària"

, "Assistant Telephone"
: "Telèfon secretari -ària"

, "Private Contact Data"
: "Dades de contacte personals"

, "Email Home"
: "Correu electrònic particular"

, "Telephone Home"
: "Telèfon particular"

, "Telephone Cellphone Private"
: "Mòbil particular"

, "Telephone Fax Home"
: "Fax particular"

, "URL Home"
: "URL personal"

, "Other Data"
: "Informació addicional"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Contactes interns"

, "All contacts I have read grants for"
: "Tots els contactes sobre els quals tenc permís de lectura"

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "gestiona les llibretes d'adreces compartides"

, "Create new shared addressbook folders"
: "Crea noves llibretes d'adreces compartides"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "Industry"
: ""

, "Contact"
: "Contacte"

, "Addressbook"
: "Llibreta d'adreces"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
